@@ -1,6 +1,6 @@
 # Class Log definition
 
-# Copyright (C) 2011 Charles Atkinson
+# Copyright (C) 2012 Charles Atkinson
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,6 +43,10 @@ class Log
     @fd.close
   end
 
+  def flush( )
+    @fd.flush
+  end
+
   def log_level( log_level )
     case log_level
       when "DEBUG"
@@ -66,23 +70,24 @@ class Log
   def write( level, msg_text )
     if level < @log_level; return end
     case level
-    when DEBUG
-      msg_text = "DEBUG: " + msg_text
-    when INFO
-    when WARN
-      @n_warnings += 1
-      msg_text = "WARNING: " + msg_text
-    when ERROR
-      @n_errors += 1
-      msg_text = "ERROR: " + msg_text
-    when FATAL
-      msg_text = "FATAL: " + msg_text
-      if @timestamps; msg_text = Time.now.strftime( '%H:%M:%S ' ) + msg_text end
-      @fd.puts( msg_text )
-      Finalise( 1 )
+      when DEBUG
+        msg_text = "DEBUG: " + msg_text
+      when INFO
+      when WARN
+        @n_warnings += 1
+        msg_text = "WARNING: " + msg_text
+      when ERROR
+        @n_errors += 1
+        msg_text = "ERROR: " + msg_text
+      when FATAL
+        msg_text = "FATAL: " + msg_text
+        if @timestamps; msg_text = Time.now.strftime( '%H:%M:%S ' ) + msg_text end
+        @fd.puts( msg_text )
+        Finalise( 1 )
     end
     if @timestamps; msg_text = Time.now.strftime( '%H:%M:%S ' ) + msg_text end
     @fd.puts( msg_text )
+    if level == "ERROR" || level == "FATAL" then self.flush( )  end
   end
 
 end
